This function is a wrapper for the
gbm::basehaz.gbm(). The function
computes the Breslow estimator of the baseline
hazard function for a proportional hazard
regression model.
sgb_bhaz(sgb_booster, eval_times = NULL, smooth = FALSE, cumulative = TRUE)
| sgb_booster | an object of class |
|---|---|
| eval_times | Values at which the baseline hazard will be evaluated. |
| smooth | If |
| cumulative | If |
A vector with a baseline hazard value corresponding to each
time in eval_times If cumulative is TRUE, the returned vector
evaluates the cumulative hazard function at those values.